@@ -46,14 +46,18 @@ struct _TrackerNamespaceClass {
 	GObjectClass parent_class;
 };
 
-GType             tracker_namespace_get_type   (void) G_GNUC_CONST;
-TrackerNamespace *tracker_namespace_new        (void);
-const gchar *     tracker_namespace_get_uri    (TrackerNamespace *namespace_);
-const gchar *     tracker_namespace_get_prefix (TrackerNamespace *namespace_);
-void              tracker_namespace_set_uri    (TrackerNamespace *namespace_,
-                                                const gchar      *value);
-void              tracker_namespace_set_prefix (TrackerNamespace *namespace_,
-                                                const gchar      *value);
+GType             tracker_namespace_get_type      (void) G_GNUC_CONST;
+TrackerNamespace *tracker_namespace_new           (void);
+const gchar *     tracker_namespace_get_uri       (TrackerNamespace *namespace_);
+const gchar *     tracker_namespace_get_prefix    (TrackerNamespace *namespace_);
+gboolean          tracker_namespace_get_is_new    (TrackerNamespace *namespace_);
+
+void              tracker_namespace_set_uri       (TrackerNamespace *namespace_,
+                                                   const gchar      *value);
+void              tracker_namespace_set_prefix    (TrackerNamespace *namespace_,
+                                                   const gchar      *value);
+void              tracker_namespace_set_is_new    (TrackerNamespace *namespace_,
+                                                   gboolean         value);
 
 G_END_DECLS
 
