@@ -27,7 +27,7 @@
 #include <libtracker-common/tracker-common.h>
 #include <libtracker-common/tracker-date-time.h>
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 
 #include <libtracker-fts/tracker-fts.h>
 
@@ -199,10 +199,10 @@ GQuark tracker_data_error_quark (void) {
 }
 
 static gint
-tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
+tracker_data_update_get_new_service_id (void)
 {
 	TrackerDBCursor    *cursor;
-	TrackerDBInterface *temp_iface;
+	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 
 	static gint         max = 0;
@@ -211,9 +211,9 @@ tracker_data_update_get_new_service_id (TrackerDBInterface *iface)
 		return ++max;
 	}
 
-	temp_iface = tracker_db_manager_get_db_interface ();
+	iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (temp_iface,
+	stmt = tracker_db_interface_create_statement (iface,
 	                                              "SELECT MAX(ID) AS A FROM Resource");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -387,7 +387,7 @@ static gint
 ensure_resource_id (const gchar *uri,
                     gboolean    *create)
 {
-	TrackerDBInterface *iface, *common;
+	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 
 	gint id;
@@ -399,11 +399,9 @@ ensure_resource_id (const gchar *uri,
 	}
 
 	if (id == 0) {
-		/* object resource not yet in the database */
-		common = tracker_db_manager_get_db_interface ();
 		iface = tracker_db_manager_get_db_interface ();
 
-		id = tracker_data_update_get_new_service_id (common);
+		id = tracker_data_update_get_new_service_id ();
 		stmt = tracker_db_interface_create_statement (iface, "INSERT INTO Resource (ID, Uri) VALUES (?, ?)");
 		tracker_db_statement_bind_int (stmt, 0, id);
 		tracker_db_statement_bind_text (stmt, 1, uri);
@@ -625,6 +623,11 @@ tracker_data_resource_buffer_flush (GError **error)
 				if (table->delete_value) {
 					/* just set value to NULL for single value properties */
 					tracker_db_statement_bind_null (stmt, param++);
+					if (property->date_time) {
+						/* also set localDate and localTime to NULL */
+						tracker_db_statement_bind_null (stmt, param++);
+						tracker_db_statement_bind_null (stmt, param++);
+					}
 				} else {
 					statement_bind_gvalue (stmt, &param, &property->value);
 				}
@@ -663,7 +666,9 @@ tracker_data_resource_buffer_flush (GError **error)
 					g_string_append (fts, g_value_get_string (g_value_array_get_nth (values, i)));
 					g_string_append_c (fts, ' ');
 				}
-				tracker_fts_update_text (resource_buffer->id, tracker_data_query_resource_id (tracker_property_get_uri (prop)), fts->str);
+				tracker_fts_update_text (resource_buffer->id,
+							 tracker_data_query_resource_id (tracker_property_get_uri (prop)),
+							 fts->str, !tracker_property_get_fulltext_no_limit (prop));
 				g_string_free (fts, TRUE);
 			}
 		}
@@ -965,6 +970,15 @@ get_property_values (TrackerProperty *property)
 				GValue gvalue = { 0 };
 				_tracker_db_result_set_get_value (result_set, 0, &gvalue);
 				if (G_VALUE_TYPE (&gvalue)) {
+					if (tracker_property_get_data_type (property) == TRACKER_PROPERTY_TYPE_DATETIME) {
+						gint time;
+
+						time = g_value_get_int (&gvalue);
+						g_value_unset (&gvalue);
+						g_value_init (&gvalue, TRACKER_TYPE_DATE_TIME);
+						/* UTC offset is irrelevant for comparison */
+						tracker_date_time_set (&gvalue, time, 0);
+					}
 					g_value_array_append (old_values, &gvalue);
 					g_value_unset (&gvalue);
 				}
@@ -1010,7 +1024,7 @@ get_old_property_values (TrackerProperty  *property,
 			 */
 			tracker_fts_update_init (resource_buffer->id);
 
-			properties = tracker_ontology_get_properties (&n_props);
+			properties = tracker_ontologies_get_properties (&n_props);
 
 			for (i = 0; i < n_props; i++) {
 				prop = properties[i];
@@ -1024,7 +1038,8 @@ get_old_property_values (TrackerProperty  *property,
 					/* delete old fts entries */
 					for (i = 0; i < old_values->n_values; i++) {
 						tracker_fts_update_text (resource_buffer->id, -1,
-						                         g_value_get_string (g_value_array_get_nth (old_values, i)));
+						                         g_value_get_string (g_value_array_get_nth (old_values, i)),
+									 !tracker_property_get_fulltext_no_limit (prop));
 					}
 				}
 			}
@@ -1047,7 +1062,8 @@ get_old_property_values (TrackerProperty  *property,
 static void
 string_to_gvalue (const gchar         *value,
                   TrackerPropertyType  type,
-                  GValue              *gvalue)
+                  GValue              *gvalue,
+                  GError             **error)
 {
 	gint object_id;
 
@@ -1073,7 +1089,7 @@ string_to_gvalue (const gchar         *value,
 	case TRACKER_PROPERTY_TYPE_DATE:
 	case TRACKER_PROPERTY_TYPE_DATETIME:
 		g_value_init (gvalue, TRACKER_TYPE_DATE_TIME);
-		tracker_date_time_set_from_string (gvalue, value);
+		tracker_date_time_set_from_string (gvalue, value, error);
 		break;
 	case TRACKER_PROPERTY_TYPE_RESOURCE:
 		object_id = ensure_resource_id (value, NULL);
@@ -1096,14 +1112,16 @@ cache_set_metadata_decomposed (TrackerProperty  *property,
 	gchar              *table_name;
 	const gchar        *field_name;
 	TrackerProperty   **super_properties;
-	GValue gvalue = { 0 };
+	GValue              gvalue = { 0 };
 	GValueArray        *old_values;
+	GError             *new_error = NULL;
 
 	/* also insert super property values */
 	super_properties = tracker_property_get_super_properties (property);
 	while (*super_properties) {
-		cache_set_metadata_decomposed (*super_properties, value, graph, error);
-		if (*error) {
+		cache_set_metadata_decomposed (*super_properties, value, graph, &new_error);
+		if (new_error) {
+			g_propagate_error (error, new_error);
 			return;
 		}
 		super_properties++;
@@ -1122,13 +1140,19 @@ cache_set_metadata_decomposed (TrackerProperty  *property,
 	fts = tracker_property_get_fulltext_indexed (property);
 
 	/* read existing property values */
-	old_values = get_old_property_values (property, error);
-	if (*error) {
+	old_values = get_old_property_values (property, &new_error);
+	if (new_error) {
 		g_free (table_name);
+		g_propagate_error (error, new_error);
 		return;
 	}
 
-	string_to_gvalue (value, tracker_property_get_data_type (property), &gvalue);
+	string_to_gvalue (value, tracker_property_get_data_type (property), &gvalue, &new_error);
+	if (new_error) {
+		g_free (table_name);
+		g_propagate_error (error, new_error);
+		return;
+	}
 
 	if (!value_set_add_value (old_values, &gvalue)) {
 		/* value already inserted */
@@ -1183,7 +1207,13 @@ delete_metadata_decomposed (TrackerProperty  *property,
 		return;
 	}
 
-	string_to_gvalue (value, tracker_property_get_data_type (property), &gvalue);
+	string_to_gvalue (value, tracker_property_get_data_type (property), &gvalue, &new_error);
+
+	if (new_error) {
+		g_free (table_name);
+		g_propagate_error (error, new_error);
+		return;
+	}
 
 	if (!value_set_remove_value (old_values, &gvalue)) {
 		/* value not found */
@@ -1245,7 +1275,7 @@ cache_delete_resource_type (TrackerClass *class,
 			gchar *class_uri;
 
 			tracker_db_result_set_get (result_set, 0, &class_uri, -1);
-			cache_delete_resource_type (tracker_ontology_get_class_by_uri (class_uri), graph);
+			cache_delete_resource_type (tracker_ontologies_get_class_by_uri (class_uri), graph);
 			g_free (class_uri);
 		} while (tracker_db_result_set_iter_next (result_set));
 
@@ -1254,7 +1284,7 @@ cache_delete_resource_type (TrackerClass *class,
 
 	/* delete all property values */
 
-	properties = tracker_ontology_get_properties (&n_props);
+	properties = tracker_ontologies_get_properties (&n_props);
 
 	for (p = 0; p < n_props; p++) {
 		gboolean            multiple_values, fts;
@@ -1357,7 +1387,7 @@ tracker_data_delete_statement (const gchar  *graph,
 	}
 
 	if (object && g_strcmp0 (predicate, RDF_PREFIX "type") == 0) {
-		class = tracker_ontology_get_class_by_uri (object);
+		class = tracker_ontologies_get_class_by_uri (object);
 		if (class != NULL) {
 			if (!in_journal_replay) {
 				tracker_db_journal_append_delete_statement_id (
@@ -1373,7 +1403,7 @@ tracker_data_delete_statement (const gchar  *graph,
 			             "Class '%s' not found in the ontology", object);
 		}
 	} else {
-		field = tracker_ontology_get_property_by_uri (predicate);
+		field = tracker_ontologies_get_property_by_uri (predicate);
 		if (field != NULL) {
 			gint id = tracker_property_get_id (field);
 			if (!in_journal_replay) {
@@ -1504,7 +1534,7 @@ tracker_data_insert_statement (const gchar            *graph,
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (in_transaction);
 
-	property = tracker_ontology_get_property_by_uri (predicate);
+	property = tracker_ontologies_get_property_by_uri (predicate);
 	if (property != NULL) {
 		if (tracker_property_get_data_type (property) == TRACKER_PROPERTY_TYPE_RESOURCE) {
 			tracker_data_insert_statement_with_uri (graph, subject, predicate, object, error);
@@ -1536,7 +1566,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (in_transaction);
 
-	property = tracker_ontology_get_property_by_uri (predicate);
+	property = tracker_ontologies_get_property_by_uri (predicate);
 	if (property == NULL) {
 		if (strcmp (predicate, TRACKER_PREFIX "uri") == 0) {
 			/* virtual tracker:uri property */
@@ -1602,7 +1632,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 	if (strcmp (predicate, RDF_PREFIX "type") == 0) {
 		/* handle rdf:type statements specially to
 		   cope with inference and insert blank rows */
-		class = tracker_ontology_get_class_by_uri (object);
+		class = tracker_ontologies_get_class_by_uri (object);
 		if (class != NULL) {
 			cache_create_service_decomposed (class, graph);
 		} else {
@@ -1660,7 +1690,7 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (in_transaction);
 
-	property = tracker_ontology_get_property_by_uri (predicate);
+	property = tracker_ontologies_get_property_by_uri (predicate);
 	if (property == NULL) {
 		g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_PROPERTY,
 		             "Property '%s' not found in the ontology", predicate);
@@ -2062,7 +2092,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 		return;
 	}
 
-	properties = tracker_ontology_get_properties (&n_props);
+	properties = tracker_ontologies_get_properties (&n_props);
 
 	stmt = tracker_db_interface_create_statement (iface, "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdf:type\") FROM \"rdfs:Resource_rdf:type\" WHERE ID = ?");
 	tracker_db_statement_bind_int (stmt, 0, resource_id);
@@ -2075,7 +2105,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 			tracker_db_result_set_get (result_set, 0, &class_uri, -1);
 
-			class = tracker_ontology_get_class_by_uri (class_uri);
+			class = tracker_ontologies_get_class_by_uri (class_uri);
 
 			if (class == NULL) {
 				g_warning ("Class '%s' not found in the ontology", class_uri);
