@@ -35,7 +35,7 @@
 
 #include <libtracker-common/tracker-date-time.h>
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-property.h>
 #include <libtracker-common/tracker-utils.h>
 
@@ -54,7 +54,7 @@
 #define TRACKER_DB_PAGE_SIZE_DONT_SET -1
 
 /* Set current database version we are working with */
-#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_11
+#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_12
 #define TRACKER_DB_VERSION_FILE       "db-version.txt"
 
 #define IN_USE_FILENAME               ".meta.isrunning"
@@ -77,7 +77,8 @@ typedef enum {
 	TRACKER_DB_VERSION_08,      /* Version 0.7.13 (coalesce & writeback) */
 	TRACKER_DB_VERSION_09,      /* Version 0.7.17 (mlo ontology) */
 	TRACKER_DB_VERSION_10,      /* Version 0.7.20 (nco im ontology) */
-	TRACKER_DB_VERSION_11       /* Version 0.7.21 (named graphs/localtime) */
+	TRACKER_DB_VERSION_11,       /* Version 0.7.21 (named graphs/localtime) */
+	TRACKER_DB_VERSION_12       /* Version 0.7.22 (fts-limits branch) */
 } TrackerDBVersion;
 
 typedef struct {
@@ -1220,10 +1221,10 @@ db_recreate_all (void)
 	 * we have cleaned up the ontology before we load all
 	 * new databases.
 	 */
-	tracker_ontology_shutdown ();
+	tracker_ontologies_shutdown ();
 
 	/* Make sure we initialize all other modules we depend on */
-	tracker_ontology_init ();
+	tracker_ontologies_init ();
 
 	/* Now create the databases and close them */
 	g_message ("Creating database files, this may take a few moments...");
@@ -1438,7 +1439,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 		db_recreate_all ();
 
 		/* Make sure we initialize all other modules we depend on */
-		tracker_ontology_init ();
+		tracker_ontologies_init ();
 
 		/* Load databases */
 		g_message ("Loading databases files...");
@@ -1447,7 +1448,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 		gboolean must_recreate;
 
 		/* Make sure we initialize all other modules we depend on */
-		tracker_ontology_init ();
+		tracker_ontologies_init ();
 
 		/* Load databases */
 		g_message ("Loading databases files...");
@@ -1599,7 +1600,7 @@ tracker_db_manager_shutdown (void)
 	db_type_enum_class_pointer = NULL;
 
 	/* Make sure we shutdown all other modules we depend on */
-	tracker_ontology_shutdown ();
+	tracker_ontologies_shutdown ();
 
 	initialized = FALSE;
 	locations_initialized = FALSE;
