@@ -33,7 +33,7 @@
 
 #include <dbus/dbus-glib-bindings.h>
 
-#include <libtracker-common/tracker-storage.h>
+#include <libtracker-miner/tracker-storage.h>
 
 #include "tracker-albumart.h"
 #include "tracker-dbus.h"
@@ -46,7 +46,7 @@
 #define ALBUMARTER_INTERFACE  "com.nokia.albumart.Requester"
 
 typedef struct {
-	TrackerStorage *hal;
+	TrackerStorage *storage;
 	gchar *art_path;
 	gchar *local_uri;
 } GetFileInfo;
@@ -443,9 +443,14 @@ albumart_heuristic (const gchar *artist,
 	for (name = g_dir_read_name (dir), count = 0, retval = FALSE;
 	     name != NULL && !retval && count < 50;
 	     name = g_dir_read_name (dir), count++) {
+            /* Accept cover, front, folder, AlbumArt_{GUID}_Large
+               reject AlbumArt_{GUID}_Small and AlbumArtSmall */
 		if ((artist_stripped && strcasestr (name, artist_stripped)) ||
 		    (album_stripped && strcasestr (name, album_stripped)) ||
-		    (strcasestr (name, "cover"))) {
+		    (strcasestr (name, "cover")) ||
+                    (strcasestr (name, "front")) ||
+                    (strcasestr (name, "folder")) ||
+                    ((strcasestr (name, "albumart") && strcasestr (name, "large")))) {
 			if (g_str_has_suffix (name, "jpeg") ||
 			    g_str_has_suffix (name, "jpg")) {
 				if (!target) {
@@ -517,26 +522,6 @@ albumart_heuristic (const gchar *artist,
 	return retval;
 }
 
-static void
-albumart_signal_queue_thumbnail (const gchar *file,
-                                 const gchar *mime)
-{
-	GObject *object;
-
-	object = tracker_dbus_get_object (TRACKER_TYPE_EXTRACT);
-	if (!object) {
-		/* This can happen if we run tracker-extract on the
-		 * command line for one file only because we don't
-		 * register the TrackerExtract object with DBus.
-		 */
-		return;
-	}
-
-	g_message ("Album art being signaled for thumbnail queue for file:'%s', mime:'%s'",
-	           file, mime);
-	g_signal_emit_by_name (object, "queue-thumbnail", file, mime);
-}
-
 static gboolean
 albumart_set (const unsigned char *buffer,
               size_t               len,
@@ -557,14 +542,13 @@ albumart_set (const unsigned char *buffer,
 
 	retval = tracker_albumart_buffer_to_jpeg (buffer, len, mime, local_path);
 
-	albumart_signal_queue_thumbnail (local_path, mime);
 	g_free (local_path);
 
 	return retval;
 }
 
 static void
-albumart_request_download (TrackerStorage *hal,
+albumart_request_download (TrackerStorage *storage,
                            const gchar    *album,
                            const gchar    *artist,
                            const gchar    *local_uri,
@@ -578,11 +562,7 @@ albumart_request_download (TrackerStorage *hal,
 
 	info = g_slice_new (GetFileInfo);
 
-#ifdef HAVE_HAL
-	info->hal = hal ? g_object_ref (hal) : NULL;
-#else
-	info->hal = NULL;
-#endif
+	info->storage = storage ? g_object_ref (storage) : NULL;
 
 	info->local_uri = g_strdup (local_uri);
 	info->art_path = g_strdup (art_path);
@@ -616,7 +596,7 @@ albumart_request_download (TrackerStorage *hal,
 }
 
 static void
-albumart_copy_to_local (TrackerStorage *hal,
+albumart_copy_to_local (TrackerStorage *storage,
                         const gchar    *filename,
                         const gchar    *local_uri)
 {
@@ -625,8 +605,7 @@ albumart_copy_to_local (TrackerStorage *hal,
 	guint flen;
 
 	/* Determining if we are on a removable device */
-#ifdef HAVE_HAL
-	if (!hal) {
+	if (!storage) {
 		/* This is usually because we are running on the
 		 * command line, so we don't error here with
 		 * g_return_if_fail().
@@ -634,11 +613,7 @@ albumart_copy_to_local (TrackerStorage *hal,
 		return;
 	}
 
-	removable_roots = tracker_storage_get_removable_device_roots (hal);
-#else
-	removable_roots = g_slist_append (removable_roots, "/media");
-	removable_roots = g_slist_append (removable_roots, "/mnt");
-#endif
+	removable_roots = tracker_storage_get_removable_device_roots (storage);
 
 	flen = strlen (filename);
 
@@ -653,10 +628,7 @@ albumart_copy_to_local (TrackerStorage *hal,
 		}
 	}
 
-#ifdef HAVE_HAL
 	g_slist_foreach (removable_roots, (GFunc) g_free, NULL);
-#endif
-
 	g_slist_free (removable_roots);
 
 	if (on_removable_device) {
@@ -713,19 +685,10 @@ albumart_queue_cb (DBusGProxy     *proxy,
 		g_clear_error (&error);
 	}
 
-	if (info->hal && info->art_path &&
+	if (info->storage && info->art_path &&
 	    g_file_test (info->art_path, G_FILE_TEST_EXISTS)) {
-		gchar *uri;
 
-		uri = g_filename_to_uri (info->art_path, NULL, NULL);
-
-		g_debug ("Downloaded album art using D-Bus service for uri:'%s'",
-		         uri);
-
-		albumart_signal_queue_thumbnail (uri, "image/jpeg");
-		g_free (uri);
-
-		albumart_copy_to_local (info->hal,
+		albumart_copy_to_local (info->storage,
 		                        info->art_path,
 		                        info->local_uri);
 	}
@@ -733,8 +696,8 @@ albumart_queue_cb (DBusGProxy     *proxy,
 	g_free (info->art_path);
 	g_free (info->local_uri);
 
-	if (info->hal) {
-		g_object_unref (info->hal);
+	if (info->storage) {
+		g_object_unref (info->storage);
 	}
 
 	g_slice_free (GetFileInfo, info);
@@ -748,11 +711,7 @@ tracker_albumart_init (void)
 
 	g_return_val_if_fail (initialized == FALSE, FALSE);
 
-#ifdef HAVE_HAL
 	albumart_storage = tracker_storage_new ();
-#else  /* HAVE_HAL */
-	albumart_storage = NULL;
-#endif /* HAVE_HAL */
 
 	/* Cache to know if we have already handled uris */
 	albumart_cache = g_hash_table_new_full (g_str_hash,
@@ -794,11 +753,9 @@ tracker_albumart_shutdown (void)
 		g_hash_table_unref (albumart_cache);
 	}
 
-#ifdef HAVE_HAL
 	if (albumart_storage) {
 		g_object_unref (albumart_storage);
 	}
-#endif /* HAVE_HAL */
 
 	initialized = FALSE;
 }
@@ -899,9 +856,6 @@ tracker_albumart_process (const unsigned char *buffer,
 			}
 		}
 
-		if (processed) {
-			albumart_signal_queue_thumbnail (filename_uri, "image/jpeg");
-		}
 	} else {
 		g_debug ("Album art already exists for uri:'%s' as '%s'",
 		         filename_uri,
