@@ -42,7 +42,7 @@
 #include <jpeglib.h>
 
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
@@ -50,6 +50,7 @@
 #include <libtracker-extract/tracker-xmp.h>
 #include <libtracker-extract/tracker-iptc.h>
 #include <libtracker-extract/tracker-exif.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #include "tracker-main.h"
 
@@ -93,6 +94,7 @@ typedef struct {
 } MergeData;
 
 static void extract_jpeg (const gchar          *filename,
+                          TrackerSparqlBuilder *preupdate,
                           TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
@@ -152,6 +154,7 @@ extract_jpeg_error_exit (j_common_ptr cinfo)
 
 static void
 extract_jpeg (const gchar          *uri,
+              TrackerSparqlBuilder *preupdate,
               TrackerSparqlBuilder *metadata)
 {
 	struct jpeg_decompress_struct cinfo;
@@ -179,7 +182,6 @@ extract_jpeg (const gchar          *uri,
 		MergeData md = { 0 };
 		gchar *comment = NULL;
 
-		tracker_sparql_builder_subject_iri (metadata, uri);
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "nfo:Image");
 		tracker_sparql_builder_predicate (metadata, "a");
@@ -232,19 +234,19 @@ extract_jpeg (const gchar          *uri,
 
 #ifdef HAVE_LIBEXIF
 				if (strncmp (EXIF_NAMESPACE, str, EXIF_NAMESPACE_LENGTH) == 0) {
-					tracker_exif_read ((unsigned char*) marker->data,
-					                   len,
-					                   uri,
-					                   &ed);
+					tracker_extract_exif_read ((unsigned char*) marker->data,
+					                           len,
+					                           uri,
+					                           &ed);
 				}
 #endif /* HAVE_LIBEXIF */
 
 #ifdef HAVE_EXEMPI
 				if (strncmp (XMP_NAMESPACE, str, XMP_NAMESPACE_LENGTH) == 0) {
-					tracker_xmp_read (str + XMP_NAMESPACE_LENGTH,
-					                  len - XMP_NAMESPACE_LENGTH,
-					                  uri,
-					                  &xd);
+					tracker_extract_xmp_read (str + XMP_NAMESPACE_LENGTH,
+					                          len - XMP_NAMESPACE_LENGTH,
+					                          uri,
+					                          &xd);
 				}
 #endif /* HAVE_EXEMPI */
 
@@ -257,10 +259,10 @@ extract_jpeg (const gchar          *uri,
 				if (strncmp (PS3_NAMESPACE, str, PS3_NAMESPACE_LENGTH) == 0) {
 					offset = iptc_jpeg_ps3_find_iptc (str, len, &sublen);
 					if (offset > 0) {
-						tracker_iptc_read (str + offset,
-						                   sublen,
-						                   uri,
-						                   &id);
+						tracker_extract_iptc_read (str + offset,
+						                           sublen,
+						                           uri,
+						                           &id);
 					}
 				}
 #endif /* HAVE_LIBIPTCDATA */
@@ -299,26 +301,26 @@ extract_jpeg (const gchar          *uri,
 			g_free (ed.make);
 		}
 
-		md.title = tracker_coalesce (3, xd.title, xd.title2, ed.document_name, xd.pdf_title);
-		md.orientation = tracker_coalesce (3, ed.orientation, xd.orientation, id.image_orientation);
-		md.copyright = tracker_coalesce (3, ed.copyright, xd.copyright, xd.rights, id.copyright_notice);
-		md.white_balance = tracker_coalesce (2, ed.white_balance, xd.white_balance);
-		md.fnumber =  tracker_coalesce (2, ed.fnumber, xd.fnumber);
-		md.flash =  tracker_coalesce (2, ed.flash, xd.flash);
-		md.focal_length =  tracker_coalesce (2, ed.focal_length, xd.focal_length);
-		md.artist =  tracker_coalesce (3, ed.artist, xd.artist, xd.contributor);
-		md.exposure_time =  tracker_coalesce (2, ed.exposure_time, xd.exposure_time);
-		md.iso_speed_ratings =  tracker_coalesce (2, ed.iso_speed_ratings, xd.iso_speed_ratings);
-		md.date =  tracker_coalesce (5, ed.time, xd.date, id.date_created, ed.time_original, xd.time_original);
-		md.description = tracker_coalesce (2, ed.description, xd.description);
-		md.metering_mode = tracker_coalesce (2, ed.metering_mode, xd.metering_mode);
+		md.title = tracker_coalesce (4, xd.title, ed.document_name, xd.title2, xd.pdf_title);
+		md.orientation = tracker_coalesce (3, xd.orientation, ed.orientation, id.image_orientation);
+		md.copyright = tracker_coalesce (4, xd.copyright, xd.rights, ed.copyright, id.copyright_notice);
+		md.white_balance = tracker_coalesce (2, xd.white_balance, ed.white_balance);
+		md.fnumber =  tracker_coalesce (2, xd.fnumber, ed.fnumber);
+		md.flash =  tracker_coalesce (2, xd.flash, ed.flash);
+		md.focal_length =  tracker_coalesce (2, xd.focal_length, ed.focal_length);
+		md.artist =  tracker_coalesce (3, xd.artist, ed.artist, xd.contributor);
+		md.exposure_time =  tracker_coalesce (2, xd.exposure_time, ed.exposure_time);
+		md.iso_speed_ratings =  tracker_coalesce (2, xd.iso_speed_ratings, ed.iso_speed_ratings);
+		md.date =  tracker_coalesce (5, xd.date, xd.time_original, ed.time, id.date_created, ed.time_original);
+		md.description = tracker_coalesce (2, xd.description, ed.description);
+		md.metering_mode = tracker_coalesce (2, xd.metering_mode, ed.metering_mode);
 
-		md.city = tracker_coalesce (2, id.city, xd.city);
-		md.state = tracker_coalesce (2, id.state, xd.state);
-		md.address = tracker_coalesce (2, id.sublocation, xd.address);
-		md.country  = tracker_coalesce (2, id.country_name, xd.country);
+		md.city = tracker_coalesce (2, xd.city, id.city);
+		md.state = tracker_coalesce (2, xd.state, id.state);
+		md.address = tracker_coalesce (2, xd.address, id.sublocation);
+		md.country  = tracker_coalesce (2, xd.country, id.country_name);
 
-		md.creator =  tracker_coalesce (3, id.byline, xd.creator, id.credit);
+		md.creator =  tracker_coalesce (3, xd.creator, id.byline, id.credit);
 		md.comment = tracker_coalesce (2, comment, ed.user_comment);
 
 		/* Prioritize on native dimention in all cases */
@@ -326,6 +328,9 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_int64 (metadata, cinfo.image_width);
 		g_free (ed.x_dimension);
 
+		/* TODO: add ontology and store this */
+		g_free (ed.software);
+
 		tracker_sparql_builder_predicate (metadata, "nfo:height");
 		tracker_sparql_builder_object_int64 (metadata, cinfo.image_height);
 		g_free (ed.y_dimension);
@@ -373,6 +378,12 @@ extract_jpeg (const gchar          *uri,
 			g_free (xd.type);
 		}
 
+		if (xd.rating) {
+			tracker_sparql_builder_predicate (metadata, "nao:numericRating");
+			tracker_sparql_builder_object_unvalidated (metadata, xd.rating);
+			g_free (xd.rating);
+		}
+
 		if (xd.format) {
 			tracker_sparql_builder_predicate (metadata, "dc:format");
 			tracker_sparql_builder_object_unvalidated (metadata, xd.format);
@@ -524,15 +535,16 @@ extract_jpeg (const gchar          *uri,
 		if (md.creator) {
 
 			if (id.byline_title) {
-				tracker_sparql_builder_subject (metadata, "_:affiliation_by_line");
-				tracker_sparql_builder_predicate (metadata, "a");
-				tracker_sparql_builder_object (metadata, "nco:Affiliation");
+				tracker_sparql_builder_insert_open (preupdate, NULL);
 
-				tracker_sparql_builder_subject (metadata, "_:affiliation_by_line");
-				tracker_sparql_builder_predicate (metadata, "nco:title");
-				tracker_sparql_builder_object_unvalidated (metadata, id.byline_title);
+				tracker_sparql_builder_subject (preupdate, "_:affiliation_by_line");
+				tracker_sparql_builder_predicate (preupdate, "a");
+				tracker_sparql_builder_object (preupdate, "nco:Affiliation");
 
-				tracker_sparql_builder_subject_iri (metadata, uri);
+				tracker_sparql_builder_predicate (preupdate, "nco:title");
+				tracker_sparql_builder_object_unvalidated (preupdate, id.byline_title);
+
+				tracker_sparql_builder_insert_close (preupdate);
 			}
 
 			tracker_sparql_builder_predicate (metadata, "nco:creator");
