@@ -45,7 +45,7 @@
 
 #include <libtracker-common/tracker-date-time.h>
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
@@ -742,7 +742,7 @@ get_id3 (const gchar *data,
 	pos += 30;
 	year = g_convert (pos, 4, "UTF-8", encoding, NULL, NULL, NULL);
 	if (atoi (year) > 0) {
-		id3->recording_time = tracker_date_format (year);
+		id3->recording_time = tracker_extract_guess_date (year);
 	}
 	g_free (year);
 
@@ -1235,11 +1235,12 @@ get_id3v24_tags (const gchar          *data,
 				tag->copyright = word;
 				break;
 			case ID3V24_TDRC:
-				tag->recording_time = tracker_date_format (word);
+				tag->recording_time = tracker_extract_guess_date (word);
 				g_free (word);
 				break;
 			case ID3V24_TDRL:
-				tag->release_time = word;
+				tag->release_time = tracker_extract_guess_date (word);
+				g_free (word);
 				break;
 			case ID3V24_TEXT:
 				tag->text = word;
@@ -1286,7 +1287,7 @@ get_id3v24_tags (const gchar          *data,
 			}
 			case ID3V24_TYER:
 				if (atoi (word) > 0) {
-					tag->recording_time = tracker_date_format (word);
+					tag->recording_time = tracker_extract_guess_date (word);
 				}
 				g_free (word);
 				break;
@@ -1488,7 +1489,7 @@ get_id3v23_tags (const gchar          *data,
 			}
 			case ID3V24_TYER:
 				if (atoi (word) > 0) {
-					tag->recording_time = tracker_date_format (word);
+					tag->recording_time = tracker_extract_guess_date (word);
 				}
 				g_free (word);
 				break;
@@ -1623,7 +1624,7 @@ get_id3v20_tags (const gchar          *data,
 				break;
 			case ID3V2_TYE:
 				if (atoi (word) > 0) {
-					tag->recording_time = tracker_date_format (word);
+					tag->recording_time = tracker_extract_guess_date (word);
 				}
 				g_free (word);
 				break;
