@@ -25,7 +25,7 @@
 
 #include <glib.h>
 
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-os-dependant.h>
 #include <libtracker-common/tracker-utils.h>
 
@@ -83,7 +83,7 @@ static const gchar *info_tags[][2] = {
 	{ "Album",              "nie:title"          },
 	{ "Year",               "nie:contentCreated" },
 	{ "copyright",          "nie:copyright"      },
-	{ NULL,                         NULL,                }
+	{ NULL,                 NULL,                }
 };
 
 typedef struct {
@@ -220,7 +220,10 @@ extract_mplayer (const gchar          *uri,
 
 								equal_char_pos = strchr (next_line, '=');
 
-								data = g_strdup (equal_char_pos + 1);
+								if (g_strcmp0 (info_tags[i][0], "Year") == 0)
+									date = tracker_extract_guess_date (equal_char_pos + 1);
+								else
+									data = g_strdup (equal_char_pos + 1);
 
 								if (data) {
 									if (data[0] != '\0') {
