@@ -22,8 +22,10 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gio/gio.h>
 
 #include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #undef  TRY_LOCALE_TO_UTF8_CONVERSION
 
