@@ -22,13 +22,14 @@
 #include <stdio.h>
 #include <string.h>
 #include <fcntl.h>
+#include <stdlib.h>
 
 #include <glib.h>
 
 #include <vorbis/vorbisfile.h>
 
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
@@ -96,7 +97,7 @@ extract_vorbis (const char *uri,
 	gchar          *filename;
 	VorbisData      vorbis_data = { 0 };
 	VorbisNeedsMergeData merge_data = { 0 };
-	gchar *artist_uri = NULL, *album_uri = NULL;
+	gchar *artist_uri = NULL, *album_uri = NULL, *publisher_uri = NULL;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 	f = tracker_file_open (filename, "r", FALSE);
@@ -112,6 +113,7 @@ extract_vorbis (const char *uri,
 	}
 
 	if ((comment = ov_comment (&vf, -1)) != NULL) {
+		gchar *date;
 		vorbis_data.title = ogg_get_comment (comment, "title");
 		vorbis_data.artist = ogg_get_comment (comment, "artist");
 		vorbis_data.album = ogg_get_comment (comment, "album");
@@ -124,7 +126,9 @@ extract_vorbis (const char *uri,
 		vorbis_data.TrackPeakGain = ogg_get_comment (comment, "TrackPeakGain");
 		vorbis_data.AlbumGain = ogg_get_comment (comment, "AlbumGain");
 		vorbis_data.AlbumPeakGain = ogg_get_comment (comment, "AlbumPeakGain");
-		vorbis_data.date = ogg_get_comment (comment, "date");
+		date = ogg_get_comment (comment, "date");
+		vorbis_data.date = tracker_extract_guess_date (date);
+		g_free (date);
 		vorbis_data.comment = ogg_get_comment (comment, "comment");
 		vorbis_data.genre = ogg_get_comment (comment, "genre");
 		vorbis_data.Codec = ogg_get_comment (comment, "Codec");
@@ -184,6 +188,7 @@ extract_vorbis (const char *uri,
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
 			tracker_sparql_builder_object_variable (preupdate, "unknown");
 			tracker_sparql_builder_delete_close (preupdate);
+
 			tracker_sparql_builder_where_open (preupdate);
 			tracker_sparql_builder_subject_iri (preupdate, album_uri);
 			tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
@@ -193,17 +198,86 @@ extract_vorbis (const char *uri,
 			tracker_sparql_builder_insert_open (preupdate, NULL);
 
 			tracker_sparql_builder_subject_iri (preupdate, album_uri);
-			tracker_sparql_builder_predicate (metadata, "nmm:albumTrackCount");
-			tracker_sparql_builder_object_unvalidated (metadata, vorbis_data.trackcount);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
+			tracker_sparql_builder_object_unvalidated (preupdate, vorbis_data.trackcount);
 
 			tracker_sparql_builder_insert_close (preupdate);
+		}
 
-			g_free (vorbis_data.trackcount);
+		if (vorbis_data.AlbumGain) {
+			tracker_sparql_builder_delete_open (preupdate, NULL);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumGain");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_delete_close (preupdate);
+
+			tracker_sparql_builder_where_open (preupdate);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumGain");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_where_close (preupdate);
+
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumGain");
+			tracker_sparql_builder_object_double (preupdate, atof (vorbis_data.AlbumGain));
+
+			tracker_sparql_builder_insert_close (preupdate);
+		}
+
+		if (vorbis_data.AlbumPeakGain) {
+			tracker_sparql_builder_delete_open (preupdate, NULL);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumPeakGain");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_delete_close (preupdate);
+
+			tracker_sparql_builder_where_open (preupdate);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumPeakGain");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_where_close (preupdate);
+
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumPeakGain");
+			tracker_sparql_builder_object_double (preupdate, atof (vorbis_data.AlbumPeakGain));
+
+			tracker_sparql_builder_insert_close (preupdate);
+		}
+
+		if (vorbis_data.DiscNo) {
+			tracker_sparql_builder_delete_open (preupdate, NULL);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_delete_close (preupdate);
+
+			tracker_sparql_builder_where_open (preupdate);
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+			tracker_sparql_builder_object_variable (preupdate, "unknown");
+			tracker_sparql_builder_where_close (preupdate);
+
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+			tracker_sparql_builder_object_int64 (preupdate, atoi (vorbis_data.DiscNo));
+
+			tracker_sparql_builder_insert_close (preupdate);
 		}
 
 		g_free (vorbis_data.album);
 	}
 
+	g_free (vorbis_data.trackcount);
+	g_free (vorbis_data.AlbumPeakGain);
+	g_free (vorbis_data.AlbumGain);
+	g_free (vorbis_data.DiscNo);
+
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
 	tracker_sparql_builder_object (metadata, "nfo:Audio");
@@ -226,15 +300,6 @@ extract_vorbis (const char *uri,
 		g_free (vorbis_data.tracknumber);
 	}
 
-	if (vorbis_data.DiscNo) {
-#if 0
-		/* nmm:setNumber is of domain nmm:MusicAlbum, but there could be several of these... */
-		tracker_sparql_builder_predicate (metadata, "nmm:setNumber");
-		tracker_sparql_builder_object_unvalidated (metadata, vorbis_data.DiscNo);
-#endif
-		g_free (vorbis_data.DiscNo);
-	}
-
 	if (vorbis_data.TrackGain) {
 		/* tracker_statement_list_insert (metadata, uri, _PREFIX "", vorbis_data.); */
 		g_free (vorbis_data.TrackGain);
@@ -244,18 +309,6 @@ extract_vorbis (const char *uri,
 		g_free (vorbis_data.TrackPeakGain);
 	}
 
-	if (vorbis_data.AlbumGain) {
-		tracker_sparql_builder_predicate (metadata, "nmm:albumGain");
-		tracker_sparql_builder_object_unvalidated (metadata, vorbis_data.AlbumGain);
-		g_free (vorbis_data.AlbumGain);
-	}
-
-	if (vorbis_data.AlbumPeakGain) {
-		tracker_sparql_builder_predicate (metadata, "nmm:albumPeakGain");
-		tracker_sparql_builder_object_unvalidated (metadata, vorbis_data.AlbumPeakGain);
-		g_free (vorbis_data.AlbumPeakGain);
-	}
-
 	if (vorbis_data.comment) {
 		tracker_sparql_builder_predicate (metadata, "nie:comment");
 		tracker_sparql_builder_object_unvalidated (metadata, vorbis_data.comment);
