@@ -30,10 +30,7 @@ G_BEGIN_DECLS
 gboolean    tracker_dbus_init                    (void);
 void        tracker_dbus_shutdown                (void);
 gboolean    tracker_dbus_register_objects        (void);
-
 GObject    *tracker_dbus_get_object              (GType type);
-void        tracker_dbus_indexer_check_is_paused (void);
-DBusGProxy *tracker_dbus_indexer_get_proxy       (void);
 
 G_END_DECLS
 
