@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia
  *
@@ -22,9 +21,13 @@
 
 #include <stdlib.h>
 #include <locale.h>
-#include <libtracker-common/tracker-log.h>
+
+#include <dbus/dbus-glib.h>
+
 #include <glib/gi18n.h>
 
+#include <libtracker-common/tracker-log.h>
+
 #include "tracker-writeback-dispatcher.h"
 #include "tracker-writeback-consumer.h"
 #include "tracker-config.h"
